[PATCH] D77865: [VPlan] Turn classes with all public members into structs (NFC).

Florian Hahn via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Sun Apr 12 03:11:16 PDT 2020


This revision was automatically updated to reflect the committed changes.
Closed by commit rGae1e353a258a: [VPlan] Turn classes with all public members into structs (NFC). (authored by fhahn).

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D77865/new/

https://reviews.llvm.org/D77865

Files:
  llvm/lib/Transforms/Vectorize/VPlanTransforms.h
  llvm/lib/Transforms/Vectorize/VPlanValue.h
  llvm/lib/Transforms/Vectorize/VPlanVerifier.h


Index: llvm/lib/Transforms/Vectorize/VPlanValue.h
===================================================================
--- llvm/lib/Transforms/Vectorize/VPlanValue.h
+++ llvm/lib/Transforms/Vectorize/VPlanValue.h
@@ -40,7 +40,7 @@
 // and live-outs which the VPlan will need to fix accordingly.
 class VPValue {
   friend class VPBuilder;
-  friend class VPlanTransforms;
+  friend struct VPlanTransforms;
   friend class VPBasicBlock;
   friend class VPInterleavedAccessInfo;
   friend class VPSlotTracker;
Index: llvm/lib/Transforms/Vectorize/VPlanTransforms.h
===================================================================
--- llvm/lib/Transforms/Vectorize/VPlanTransforms.h
+++ llvm/lib/Transforms/Vectorize/VPlanTransforms.h
@@ -19,9 +19,7 @@
 
 namespace llvm {
 
-class VPlanTransforms {
-
-public:
+struct VPlanTransforms {
   /// Replaces the VPInstructions in \p Plan with corresponding
   /// widen recipes.
   static void VPInstructionsToVPRecipes(


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D77865.256845.patch
Type: text/x-patch
Size: 1717 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20200412/bae3d399/attachment.bin>


More information about the llvm-commits mailing list
Index: llvm/lib/Transforms/Vectorize/VPlanVerifier.h
===================================================================
--- llvm/lib/Transforms/Vectorize/VPlanVerifier.h
+++ llvm/lib/Transforms/Vectorize/VPlanVerifier.h
@@ -28,10 +28,9 @@
 
 namespace llvm {
 
 /// Class with utility functions that can be used to check the consistency and
 /// invariants of a VPlan, including the components of its H-CFG.
-class VPlanVerifier {
-public:
+struct VPlanVerifier {
   /// Verify the invariants of the H-CFG starting from \p TopRegion. The
   /// verification process comprises the following steps:
   /// 1. Region/Block verification: Check the Region/Block verification
@@ -28,10 +28,9 @@
 namespace llvm {
 
-/// Class with utility functions that can be used to check the consistency and
+/// Struct with utility functions that can be used to check the consistency and
 /// invariants of a VPlan, including the components of its H-CFG.